@@ -117,6 +117,9 @@ typedef uint32_t GMM_GLOBAL_GFX_ADDRESS, GMM_GLOBAL_GFX_SIZE_T;
 #define GMM_GFX_ADDRESS_CANONIZE(a)     (((int64_t)(a) << (64 - 48)) >> (64 - 48)) // TODO(Minor): When GMM adds platform-dependent VA size caps, change from 48.
 #define GMM_GFX_ADDRESS_DECANONIZE(a)   ((uint64_t)(a) & (((uint64_t) 1 << 48) - 1)) // "
 
+#define GMM_GFX_PLATFORM_VA_SIZE(pClientContext)        (((pClientContext)->GetLibContext()->GetSkuTable().Ftr57bGPUAddressing) ? 57 : 48)
+#define VASize(pCC)                                     GMM_GFX_PLATFORM_VA_SIZE(pCC)
+
 #define GMM_BIT_RANGE(endbit, startbit)     ((endbit)-(startbit)+1)
 #define GMM_BIT(bit)                        (1)
 
@@ -172,6 +175,16 @@ else                                                \
     ClientType = GMM_UNDEFINED_CLIENT;              \
 }                                                   \
 
+#define GET_RES_CLIENT_TYPE(pResourceInfo, ClientType)  \
+if(pResourceInfo)                                       \
+{                                                       \
+    ClientType = (pResourceInfo)->GetClientType();      \
+}                                                       \
+else                                                    \
+{                                                       \
+    ClientType = GMM_UNDEFINED_CLIENT;                  \
+}                                                       \
+
 //===========================================================================
 // typedef:
 //     GMM_TEXTURE_LAYOUT
@@ -197,7 +210,9 @@ typedef enum GMM_TILE_TYPE_ENUM
     GMM_TILED_X,
     GMM_TILED_Y,
     GMM_TILED_W,
-    GMM_NOT_TILED
+    GMM_NOT_TILED,
+    GMM_TILED_4,
+    GMM_TILED_64
 }GMM_TILE_TYPE;
 
 //===========================================================================
@@ -402,7 +417,7 @@ typedef enum GMM_RESOURCE_FORMAT_ENUM
 {
     GMM_FORMAT_INVALID = 0, // <-- This stays zero! (For boolean and valid range checks.)
 
-    #define GMM_FORMAT(Name, bpe, Width, Height, Depth, IsRT, IsASTC, RcsSurfaceFormat, AuxL1eFormat, Availability) \
+    #define GMM_FORMAT(Name, bpe, Width, Height, Depth, IsRT, IsASTC, RcsSurfaceFormat, SSCompressionFmt, Availability) \
         GMM_FORMAT_##Name, \
         GMM_FORMAT_##Name##_TYPE = GMM_FORMAT_##Name, // TODO(Minor): Remove _TYPE suffix from every GMM_FORMAT_ reference throughout driver and delete this aliasing. (And remove the \ from the line above.)
     #include "GmmFormatTable.h"
@@ -429,7 +444,7 @@ typedef enum GMM_SURFACESTATE_FORMAT_ENUM
     GMM_SURFACESTATE_FORMAT_INVALID = -1, // Can't use zero since that's an actual enum value.
 
     #define GMM_FORMAT_INCLUDE_SURFACESTATE_FORMATS_ONLY
-    #define GMM_FORMAT(Name, bpe, Width, Height, Depth, IsRT, IsASTC, RcsSurfaceFormat, AuxL1eFormat, Availability) \
+    #define GMM_FORMAT(Name, bpe, Width, Height, Depth, IsRT, IsASTC, RcsSurfaceFormat, SSCompressionFmt, Availability) \
         GMM_SURFACESTATE_FORMAT_##Name = RcsSurfaceFormat,
     #include "GmmFormatTable.h"
 } GMM_SURFACESTATE_FORMAT;
@@ -513,7 +528,9 @@ typedef enum GMM_TILE_WALK_REC
     GMM_HW_TILED_W_WALK     = 2,
     GMM_HW_TILED_YF_WALK    = 3,
     GMM_HW_TILED_YS_WALK    = 4,
-    GMM_HW_NOT_TILED        = 5
+    GMM_HW_TILED_4_WALK     = 5,
+    GMM_HW_TILED_64_WALK    = 6,
+    GMM_HW_NOT_TILED        = 7
 } GMM_TILE_WALK;
 
 //===========================================================================
